@@ -14,6 +14,8 @@ Description:
 
 import base64
 import inspect
+import socket
+import requests
 from typing import List, Set, Tuple
 
 from cp_common.log import logger
@@ -79,3 +81,26 @@ def get_basic_auth_str(username, password):
     # base64 编码
     encodestr = base64.b64encode(bytesString)
     return "Basic " + encodestr.decode()
+
+
+def get_host_ip():
+    """
+    查询本机ip地址
+    :return: ip
+    """
+    try:
+        s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+        s.connect(('8.8.8.8', 80))
+        ip = s.getsockname()[0]
+    finally:
+        s.close()
+
+    return ip
+
+def get_public_ip():
+    try:
+        url = "http://httpbin.org/ip"
+        response = requests.request("GET", url)
+        return response.json()["origin"]
+    except:
+        return ""
\ No newline at end of file
